@@ -34,23 +34,22 @@ import subprocess
 import sys
 import webbrowser
 from pathlib import Path
-from typing import Any, Sequence
+from typing import Sequence
 
 import click
 from click import secho
 
-from kedro.framework.cli.cli import _handle_exception
+from kedro.framework.cli.jupyter import _load_project_context
 from kedro.framework.cli.utils import (
     KedroCliError,
     _check_module_importable,
     call,
     env_option,
     forward_command,
-    get_source_dir,
     ipython_message,
     python_call,
 )
-from kedro.framework.context import load_context
+from kedro.framework.context import get_static_project_data
 
 NO_DEPENDENCY_MESSAGE = """{module} is not installed. Please make sure {module} is in
 {src}/requirements.txt and run `kedro install`."""
@@ -59,18 +58,6 @@ unformatted imports, and unblackened Python code without modifying the files."""
 OPEN_ARG_HELP = """Open the documentation in your default browser after building."""
 
 
-def _load_project_context(**kwargs: Any):
-    """Returns project context."""
-    try:
-        return load_context(Path.cwd(), **kwargs)
-    except Exception as err:  # pylint: disable=broad-except
-        env = kwargs.get("env")
-        _handle_exception(
-            f"Unable to load Kedro context with environment `{env}`. "
-            f"Make sure it exists in the project configuration.\nError: {err}"
-        )
-
-
 def _build_reqs(source_path: Path, args: Sequence[str] = ()):
     """Run `pip-compile requirements.in` command.
 
@@ -89,6 +76,10 @@ def _build_reqs(source_path: Path, args: Sequence[str] = ()):
     python_call("piptools", ["compile", "-q", *args, str(requirements_in)])
 
 
+def _get_source_path():
+    return get_static_project_data(Path.cwd())["source_dir"]
+
+
 @click.group()
 def project_group():
     """Collection of project commands."""
@@ -98,14 +89,12 @@ def project_group():
 def test(args):
     """Run the test suite."""
     try:
-        # pylint: disable=import-outside-toplevel,unused-import
-        import pytest  # noqa
-    except ImportError:
-        context = _load_project_context()
-        source_path = get_source_dir(context.project_path)
+        _check_module_importable("pytest")
+    except KedroCliError as exc:
+        source_path = _get_source_path()
         raise KedroCliError(
             NO_DEPENDENCY_MESSAGE.format(module="pytest", src=str(source_path))
-        )
+        ) from exc
     else:
         python_call("pytest", args)
 
@@ -114,23 +103,24 @@ def test(args):
 @click.option("-c", "--check-only", is_flag=True, help=LINT_CHECK_ONLY_HELP)
 @click.argument("files", type=click.Path(exists=True), nargs=-1)
 def lint(files, check_only):
-    """Run flake8, isort and (on Python >=3.6) black."""
-    context = _load_project_context()
-    source_path = get_source_dir(context.project_path)
-    files = files or (
-        str(source_path / "tests"),
-        str(source_path / context.package_name),
-    )
+    """Run flake8, isort and black."""
+    static_data = get_static_project_data(Path.cwd())
+    source_path = static_data["source_dir"]
+    package_name = static_data["package_name"]
+    files = files or (str(source_path / "tests"), str(source_path / package_name))
 
-    try:
-        # pylint: disable=import-outside-toplevel, unused-import
-        import flake8  # noqa
-        import isort  # noqa
-        import black  # noqa
-    except ImportError as exc:
-        raise KedroCliError(
-            NO_DEPENDENCY_MESSAGE.format(module=exc.name, src=str(source_path))
-        )
+    if "PYTHONPATH" not in os.environ:
+        # isort needs the source path to be in the 'PYTHONPATH' environment
+        # variable to treat it as a first-party import location
+        os.environ["PYTHONPATH"] = str(source_path)
+
+    for module_name in ("flake8", "isort", "black"):
+        try:
+            _check_module_importable(module_name)
+        except KedroCliError as exc:
+            raise KedroCliError(
+                NO_DEPENDENCY_MESSAGE.format(module=module_name, src=str(source_path))
+            ) from exc
 
     python_call("black", ("--check",) + files if check_only else files)
     python_call("flake8", ("--max-line-length=88",) + files)
@@ -155,7 +145,7 @@ def install(compile_flag):
     # we cannot use `context.project_path` as in other commands since
     # context instantiation might break due to missing dependencies
     # we attempt to install here
-    source_path = get_source_dir(Path.cwd())
+    source_path = _get_source_path()
     environment_yml = source_path / "environment.yml"
     requirements_in = source_path / "requirements.in"
     requirements_txt = source_path / "requirements.txt"
@@ -184,6 +174,7 @@ def ipython(env, args):
     """Open IPython with project specific variables loaded."""
     context = _load_project_context(env=env)
     _check_module_importable("IPython")
+
     os.environ["IPYTHONDIR"] = str(context.project_path / ".ipython")
     if env:
         os.environ["KEDRO_ENV"] = env
@@ -195,8 +186,7 @@ def ipython(env, args):
 @project_group.command()
 def package():
     """Package the project as a Python egg and wheel."""
-    context = _load_project_context()
-    source_path = get_source_dir(context.project_path)
+    source_path = _get_source_path()
     call(
         [sys.executable, "setup.py", "clean", "--all", "bdist_egg"],
         cwd=str(source_path),
@@ -219,11 +209,13 @@ def package():
 )
 def build_docs(open_docs):
     """Build the project documentation."""
-    context = _load_project_context()
-    source_path = get_source_dir(context.project_path)
+    static_data = get_static_project_data(Path.cwd())
+    source_path = static_data["source_dir"]
+    package_name = static_data["package_name"]
+
     python_call("pip", ["install", str(source_path / "[docs]")])
     python_call("pip", ["install", "-r", str(source_path / "requirements.txt")])
-    python_call("ipykernel", ["install", "--user", f"--name={context.package_name}"])
+    python_call("ipykernel", ["install", "--user", f"--name={package_name}"])
     shutil.rmtree("docs/build", ignore_errors=True)
     call(
         [
@@ -231,7 +223,7 @@ def build_docs(open_docs):
             "--module-first",
             "-o",
             "docs/source",
-            str(source_path / context.package_name),
+            str(source_path / package_name),
         ]
     )
     call(["sphinx-build", "-M", "html", "docs/source", "docs/build", "-a"])
@@ -244,10 +236,7 @@ def build_docs(open_docs):
 @forward_command(project_group, name="build-reqs")
 def build_reqs(args):
     """Build the project dependency requirements."""
-    # we cannot use `context.project_path` as in other commands since
-    # context instantiation might break due to missing dependencies
-    # we attempt to install here
-    source_path = get_source_dir(Path.cwd())
+    source_path = _get_source_path()
     _build_reqs(source_path, args)
     secho(
         "Requirements built! Please update requirements.in "
@@ -260,8 +249,7 @@ def build_reqs(args):
 @project_group.command("activate-nbstripout")
 def activate_nbstripout():
     """Install the nbstripout git hook to automatically clean notebooks."""
-    context = _load_project_context()
-    source_path = get_source_dir(context.project_path)
+    source_path = _get_source_path()
     secho(
         (
             "Notebook output cells will be automatically cleared before committing"
@@ -271,12 +259,11 @@ def activate_nbstripout():
     )
 
     try:
-        # pylint: disable=import-outside-toplevel, unused-import
-        import nbstripout  # noqa
-    except ImportError:
+        _check_module_importable("nbstripout")
+    except KedroCliError as exc:
         raise KedroCliError(
             NO_DEPENDENCY_MESSAGE.format(module="nbstripout", src=str(source_path))
-        )
+        ) from exc
 
     try:
         res = subprocess.run(  # pylint: disable=subprocess-run-check
@@ -286,7 +273,7 @@ def activate_nbstripout():
         )
         if res.returncode:
             raise KedroCliError("Not a git repository. Run `git init` first.")
-    except FileNotFoundError:
-        raise KedroCliError("Git executable not found. Install Git first.")
+    except FileNotFoundError as exc:
+        raise KedroCliError("Git executable not found. Install Git first.") from exc
 
     call(["nbstripout", "--install"])
