@@ -80,13 +80,11 @@ class _SharedMemoryDataSet:
             # Checks if the error is due to serialisation or not
             try:
                 pickle.dumps(data)
-            except Exception:  # SKIP_IF_NO_SPARK
+            except Exception as exc:  # SKIP_IF_NO_SPARK
                 raise DataSetError(
-                    "{} cannot be serialized. ParallelRunner implicit memory datasets "
-                    "can only be used with serializable data".format(
-                        str(data.__class__)
-                    )
-                )
+                    f"{str(data.__class__)} cannot be serialized. ParallelRunner "
+                    "implicit memory datasets can only be used with serializable data"
+                ) from exc
             else:
                 raise exc
 
@@ -152,7 +150,7 @@ class ParallelRunner(AbstractRunner):
                 and CPU core count. On windows machines, the max_workers value
                 cannot be larger than 61 and will be set to min(61, max_workers).
             is_async: If True, the node inputs and outputs are loaded and saved
-                    asynchronously with threads. Defaults to False.
+                asynchronously with threads. Defaults to False.
 
         Raises:
             ValueError: bad parameters passed
