@@ -226,16 +226,16 @@ def _run_node_sequential(node: Node, catalog: DataCatalog, run_id: str = None) -
     )
     try:
         outputs = node.run(inputs)
-    except Exception as error:
+    except Exception as exc:
         hook_manager.hook.on_node_error(  # pylint: disable=no-member
-            error=error,
+            error=exc,
             node=node,
             catalog=catalog,
             inputs=inputs,
             is_async=is_async,
             run_id=run_id,
         )
-        raise error
+        raise exc
     hook_manager.hook.after_node_run(  # pylint: disable=no-member
         node=node,
         catalog=catalog,
@@ -264,16 +264,16 @@ def _run_node_async(node: Node, catalog: DataCatalog, run_id: str = None) -> Nod
         )
         try:
             outputs = node.run(inputs)
-        except Exception as error:
+        except Exception as exc:
             hook_manager.hook.on_node_error(  # pylint: disable=no-member
-                error=error,
+                error=exc,
                 node=node,
                 catalog=catalog,
                 inputs=inputs,
                 is_async=is_async,
                 run_id=run_id,
             )
-            raise error
+            raise exc
         hook_manager.hook.after_node_run(  # pylint: disable=no-member
             node=node,
             catalog=catalog,
